@@ -1,7 +1,8 @@
 cluster.graph <-
 function(rl)
   {
-	if (class(rl)!="landscape") 
+  if(!inherits(rl, "landscape"))
+	#if (class(rl)!="landscape") 
   {
   stop(paste(rl, " should be an object of class class 'landscape'.", sep=""), call. = FALSE)
   }
