@@ -2,10 +2,13 @@ import.shape <-
 function(filename, path=NULL, species.col, ID.col, area.col, dispersal, class.landscape=FALSE)
   {
     pathfile <- paste(path, filename,sep="")
-    sf <- readShapePoly(pathfile)
-    df1 <- sf@data
-    ctr <- gCentroid(sf, byid=TRUE)
-    ctr<-as.data.frame(ctr)
+    #sf <- readShapePoly(pathfile)
+    sf <- terra::vect(pathfile)#NEW
+    #df1 <- sf@data
+    df1 <- as.data.frame(sf)#NEW
+    #ctr <- gCentroid(sf, byid=TRUE)
+    ctr <- terra::centroids(sf)
+    ctr<-as.data.frame(terra::crds(ctr))#NEW
     ID <- df1[, ID.col]
     area <- df1[, area.col]
     if(is.character(species.col)) species <- df1[, species.col]
